# eis-auth
The EMIL AuthService API description

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 1.11.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.emil.de](https://www.emil.de)

## Requirements.

Python >=3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install eis.auth
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/emilDev/eis-auth-sdk.git`)

Then import the package:
```python
import eis.auth
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import eis.auth
```

## Getting Started

The environment variables must be set in order to properly use this SDK.

```shell 
export EMIL_USERNAME=XXXXXXX
export EMIL_PASSWORD=XXXXXXX
```

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
import time
import eis.auth
from pprint import pprint
from eis.auth.api import authservice_api
from eis.auth.model.create_org_and_user_request_dto import CreateOrgAndUserRequestDto
from eis.auth.model.create_org_and_user_response_class import CreateOrgAndUserResponseClass
from eis.auth.model.create_user_request_dto import CreateUserRequestDto
from eis.auth.model.create_user_response_class import CreateUserResponseClass
from eis.auth.model.forgot_password_request_dto import ForgotPasswordRequestDto
from eis.auth.model.login_by_saml_request_dto import LoginBySamlRequestDto
from eis.auth.model.login_class import LoginClass
from eis.auth.model.login_request_dto import LoginRequestDto
from eis.auth.model.logout_request_dto import LogoutRequestDto
from eis.auth.model.refresh_token_dto import RefreshTokenDto
from eis.auth.model.reset_password_request_dto import ResetPasswordRequestDto
from eis.auth.model.verify_org_invitation_response_class import VerifyOrgInvitationResponseClass
# Defining the host is optional and defaults to https://apiv2.emil.de
# See configuration.py for a list of all supported configuration parameters.
configuration = eis.auth.Configuration(
    host = "https://apiv2.emil.de"
)



# Enter a context with an instance of the API client
with eis.auth.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = authservice_api.AuthserviceApi(api_client)
    create_org_and_user_request_dto = CreateOrgAndUserRequestDto(
        street="Knesebeckstraße",
        house_number="28",
        city="Berlin",
        country="Germany",
        custom_fields={},
        first_name="Camilla",
        invitation_token="ZR7p9skMDPkwtuTxWPMwl",
        is_eula_accepted=True,
        last_name="Konopelski",
        password="nS4wOqDuASGaN3T",
        zip_code="82142",
    ) # CreateOrgAndUserRequestDto | 

    try:
        # Register Organization and User using invitation token
        api_response = api_instance.create_org_and_user(create_org_and_user_request_dto)
        pprint(api_response)
    except eis.auth.ApiException as e:
        print("Exception when calling AuthserviceApi->create_org_and_user: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://apiv2.emil.de*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AuthserviceApi* | [**create_org_and_user**](docs/AuthserviceApi.md#create_org_and_user) | **POST** /authservice/v1/create-org-and-user | Register Organization and User using invitation token
*AuthserviceApi* | [**create_user**](docs/AuthserviceApi.md#create_user) | **POST** /authservice/v1/create-user | Register tenant user after invite
*AuthserviceApi* | [**forgot_password**](docs/AuthserviceApi.md#forgot_password) | **POST** /authservice/v1/forgot-password | Forgot password by tenant
*AuthserviceApi* | [**get_saml_login_link**](docs/AuthserviceApi.md#get_saml_login_link) | **GET** /authservice/v1/saml-login-link | Get SAML login link for tenant
*AuthserviceApi* | [**login**](docs/AuthserviceApi.md#login) | **POST** /authservice/v1/login | Login by tenant
*AuthserviceApi* | [**login_by_saml**](docs/AuthserviceApi.md#login_by_saml) | **POST** /authservice/v1/login/saml | Login by SAML idp provider such as ADFS
*AuthserviceApi* | [**logout**](docs/AuthserviceApi.md#logout) | **POST** /authservice/v1/logout | Logout tenant
*AuthserviceApi* | [**refresh_token**](docs/AuthserviceApi.md#refresh_token) | **POST** /authservice/v1/refresh-token | Refresh token by tenant
*AuthserviceApi* | [**reset_password**](docs/AuthserviceApi.md#reset_password) | **POST** /authservice/v1/reset-password | Change password by tenant
*AuthserviceApi* | [**verify_invite**](docs/AuthserviceApi.md#verify_invite) | **GET** /authservice/v1/verify-invite | Verify tenant user&#39;s invite token
*AuthserviceApi* | [**verify_org_invitation**](docs/AuthserviceApi.md#verify_org_invitation) | **GET** /authservice/v1/verify-org-invitation | Verify a organization&#39;s invitation token
*AuthserviceApi* | [**verify_reset_password_token**](docs/AuthserviceApi.md#verify_reset_password_token) | **GET** /authservice/v1/verify-reset-password | Verify tenant reset password token
*DefaultApi* | [**check**](docs/DefaultApi.md#check) | **GET** /authservice/health | Health Check


## Documentation For Models

 - [CreateOrgAndUserRequestDto](docs/CreateOrgAndUserRequestDto.md)
 - [CreateOrgAndUserResponseClass](docs/CreateOrgAndUserResponseClass.md)
 - [CreateUserRequestDto](docs/CreateUserRequestDto.md)
 - [CreateUserResponseClass](docs/CreateUserResponseClass.md)
 - [CustomSchemaClass](docs/CustomSchemaClass.md)
 - [ForgotPasswordRequestDto](docs/ForgotPasswordRequestDto.md)
 - [GetSamlLoginLinkRequestDto](docs/GetSamlLoginLinkRequestDto.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InlineResponse503](docs/InlineResponse503.md)
 - [LoginBySamlRequestDto](docs/LoginBySamlRequestDto.md)
 - [LoginClass](docs/LoginClass.md)
 - [LoginRequestDto](docs/LoginRequestDto.md)
 - [LogoutRequestDto](docs/LogoutRequestDto.md)
 - [OrgInvitationClass](docs/OrgInvitationClass.md)
 - [OrganizationClass](docs/OrganizationClass.md)
 - [RefreshTokenDto](docs/RefreshTokenDto.md)
 - [ResetPasswordRequestDto](docs/ResetPasswordRequestDto.md)
 - [RoleClass](docs/RoleClass.md)
 - [UserClass](docs/UserClass.md)
 - [VerifyOrgInvitationRequestDto](docs/VerifyOrgInvitationRequestDto.md)
 - [VerifyOrgInvitationResponseClass](docs/VerifyOrgInvitationResponseClass.md)


## Documentation For Authorization


## bearer

- **Type**: Bearer authentication (JWT)


## Author

kontakt@emil.de


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in eis.auth.apis and eis.auth.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from eis.auth.api.default_api import DefaultApi`
- `from eis.auth.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import eis.auth
from eis.auth.apis import *
from eis.auth.models import *
```

